@@ -1,17 +1,13 @@
+from typing import Optional, Type, TypedDict, TypeVar, Union
+
+from fastapi.requests import Request
 from pydantic import BaseModel
 from sqlalchemy.orm import Session
-from fastapi.requests import Request
-from typing import Union, TypedDict, Type, TypeVar, Optional
 
 Table = TypeVar("Table")
 Record = TypeVar('Record')
 
 
-class PaginationParams(TypedDict):
-    request: Request
-    session: Session
-
-
 class LimitOffsetPageParams(BaseModel):
     count: Union[int, None]
     total: Union[int, None]
