@@ -1,4 +1,4 @@
-from sqlalchemy import create_engine, Column, Integer, DateTime
+from sqlalchemy import Column, DateTime, Integer, create_engine
 from sqlalchemy.ext.asyncio import AsyncSession, create_async_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
