@@ -1,51 +1,28 @@
-"""Tests for BaseSyncAPI and mixins."""
+"""Tests for sqlalchemy SyncAPI and mixins."""
+
 import pytest
-from unittest.mock import MagicMock
-
 from fastapi import HTTPException
-from fastapi.requests import Request
 from pydantic import ValidationError
-
 from sqlalchemy import select
 from sqlalchemy.sql import Select
 
-from fastapi_views.views.async_api import BaseAsyncAPI
-from fastapi_views.views.mixins import (
-    BaseAPIListMixin,
-    BaseAPIDetailMixin,
-    BaseAPICreateMixin,
-    BaseAPIUpdateMixin,
-    BaseAPIDestroyMixin,
-    BaseAPIMixin,
+from fastapi_views.ext.sql_alchemy.async_api import AsyncAPI
+from fastapi_views.ext.sql_alchemy.mixins import (
+    APICreateMixin,
+    APIDestroyMixin,
+    APIDetailMixin,
+    APIListMixin,
+    APIMixin,
+    APIUpdateMixin
 )
-from fastapi_views.views.sync_api import BaseSyncAPI
+from fastapi_views.ext.sql_alchemy.pagination.core import PaginationCursor
+from fastapi_views.ext.sql_alchemy.sync_api import SyncAPI
 from fastapi_views.tests._db_sessions import DatabaseSession
 from fastapi_views.tests._tmp_db import SimpleTestOrm
-from fastapi_views.pagination.core import PaginationCursor
 
 NUMBER_OF_OBJECTS = 50  # number of objects created by sync db
 
 
-class MockRequest:
-    """Request cls required to test pagination."""
-
-    class State:
-        def __init__(self):
-            self.paginate_by = None
-
-    def __init__(self):
-        self.state = self.State()
-        self.query_params = None
-        self.url = None
-
-
-@pytest.fixture
-def request_fixture():
-    mock = MagicMock(spec=Request, return_value=MockRequest())
-    mock.url = 'https://example.com'
-    return mock
-
-
 @pytest.fixture
 def session():
     db_session = DatabaseSession()
@@ -58,7 +35,7 @@ def session():
 @pytest.fixture
 def api(request):
     model, pk_field, _, paginate_by, strategy, kwargs, statement = request.param
-    return BaseSyncAPI(
+    return SyncAPI(
         model=model,
         pk_field=pk_field,
         paginate_by=paginate_by,
@@ -74,7 +51,7 @@ def base_mixin_instance(request):
     args = ['a', 1, 'c', {'d'}]
     kwargs = {'a': 1}
 
-    class BaseView(BaseAPIMixin):
+    class BaseView(APIMixin):
         model = SimpleTestOrm
         async_api = _async_api
 
@@ -85,7 +62,7 @@ def base_mixin_instance(request):
 def list_mixin_instance(request):
     _model, _, _paginate_by, _strategy = request.param
 
-    class ListView(BaseAPIListMixin):
+    class ListView(APIListMixin):
         model = _model
         paginate_by = _paginate_by
         pagination_strategy = _strategy
@@ -97,7 +74,7 @@ def list_mixin_instance(request):
 def list_mixin_instance_override_get_statement(request):
     _model = request.param
 
-    class ListView(BaseAPIListMixin):
+    class ListView(APIListMixin):
         model = _model
 
         def get_statement(self) -> Select:
@@ -110,7 +87,7 @@ def list_mixin_instance_override_get_statement(request):
 def detail_mixin_instance(request):
     _model = request.param
 
-    class DetailView(BaseAPIDetailMixin):
+    class DetailView(APIDetailMixin):
         model = _model
 
     return DetailView()
@@ -120,7 +97,7 @@ def detail_mixin_instance(request):
 def detail_mixin_instance_override_get_statement(request):
     _model = request.param
 
-    class DetailView(BaseAPIDetailMixin):
+    class DetailView(APIDetailMixin):
         model = _model
 
         def get_statement(self) -> Select:
@@ -133,7 +110,7 @@ def detail_mixin_instance_override_get_statement(request):
 def create_mixin_instance(request):
     _model = request.param
 
-    class CreateView(BaseAPICreateMixin):
+    class CreateView(APICreateMixin):
         model = _model
 
     return CreateView()
@@ -143,7 +120,7 @@ def create_mixin_instance(request):
 def update_mixin_instance(request):
     _model = request.param
 
-    class UpdateView(BaseAPIUpdateMixin):
+    class UpdateView(APIUpdateMixin):
         model = _model
 
     return UpdateView()
@@ -153,26 +130,26 @@ def update_mixin_instance(request):
 def delete_mixin_instance(request):
     _model = request.param
 
-    class DeleteView(BaseAPIDestroyMixin):
+    class DeleteView(APIDestroyMixin):
         model = _model
 
     return DeleteView()
 
 
-class TestBaseSyncAPI:
-    """Test BaseSyncAPI cls."""
+class TestSyncAPI:
+    """Test SyncAPI cls."""
 
     @pytest.mark.parametrize('test_input', [None, ''])
     def test_init_model_raise_value_error(self, test_input):
         """Test if value error occurs on given inputs."""
         with pytest.raises(ValueError):
-            assert BaseSyncAPI(model=test_input)
+            assert SyncAPI(model=test_input)
 
     @pytest.mark.parametrize('test_input', ['not_cls', 1, True, {'a': 'b'}, {1}])
     def test_init_model_raise_validation_error(self, test_input):
         """Test if pydantic validation error occurs on given inputs."""
         with pytest.raises(ValidationError):
-            assert BaseSyncAPI(model=test_input)
+            assert SyncAPI(model=test_input)
 
     @pytest.mark.parametrize(
         'api',
@@ -414,9 +391,9 @@ class TestBaseSyncAPI:
         [(SimpleTestOrm, 'id', None, None, None, None, None)],
         indirect=['api'],
     )
-    def test_update_single(self, session, api):
-        """Test update_single method."""
-        api.update_single(
+    def test_update_one(self, session, api):
+        """Test update_one method."""
+        api.update_one(
             session=session,
             field_value=1,
             data={
@@ -432,26 +409,26 @@ class TestBaseSyncAPI:
         [(SimpleTestOrm, 'id', None, None, None, None, None)],
         indirect=['api'],
     )
-    def test_update_single_missing_attrs(self, session, api):
-        """Test update_single method attrs."""
+    def test_update_one_missing_attrs(self, session, api):
+        """Test update_one method attrs."""
         with pytest.raises(TypeError):
-            api.update_single()
+            api.update_one()
         with pytest.raises(AttributeError):
-            api.update_single(session=None, field_value=2)
+            api.update_one(session=None, field_value=2)
 
         with pytest.raises(TypeError):
-            api.update_single(session='not_valid_type', field_value=2)
+            api.update_one(session='not_valid_type', field_value=2)
 
         with pytest.raises(HTTPException):
-            api.update_single(session=session, field_value=2)
+            api.update_one(session=session, field_value=2)
 
         api.pk_field = None
         with pytest.raises(AttributeError):
-            api.update_single(session=session, field_value=2, data={'id': 100})
+            api.update_one(session=session, field_value=2, data={'id': 100})
 
         api.pk_field = 'id'
         with pytest.raises(HTTPException):
-            api.update_single(session=session, field_value=2, data={'id': 'invalid'})
+            api.update_one(session=session, field_value=2, data={'id': 'invalid'})
 
         assert api.get_detail(session, 2).id == 2
 
@@ -619,7 +596,7 @@ class TestMixins:
         [False, True],
         indirect=['base_mixin_instance'],
     )
-    def test_init(self, base_mixin_instance: BaseAPIMixin):
+    def test_init(self, base_mixin_instance: APIMixin):
         """Test base mixin initialized as expected."""
         assert base_mixin_instance.args == ('a', 1, 'c', {'d'})
         assert base_mixin_instance.kwargs == {'a': 1}
@@ -630,21 +607,21 @@ class TestMixins:
     def test_init_async_api_type_error(self, input_value):
         """Test base mixin async_api attr."""
         with pytest.raises(TypeError):
-            class BaseView(BaseAPIMixin):
+            class BaseView(APIMixin):
                 model = SimpleTestOrm
                 async_api = input_value
 
             BaseView()
 
     @pytest.mark.parametrize('base_mixin_instance', [False], indirect=['base_mixin_instance'])
-    def test_init_async_false(self, base_mixin_instance: BaseAPIMixin):
+    def test_init_async_false(self, base_mixin_instance: APIMixin):
         """Test if api_view is instance of sync API when async_api set to False."""
-        assert isinstance(base_mixin_instance.api_view, BaseSyncAPI)
+        assert isinstance(base_mixin_instance.api_view, SyncAPI)
 
     @pytest.mark.parametrize('base_mixin_instance', [True], indirect=['base_mixin_instance'])
-    def test_init_async_true(self, base_mixin_instance: BaseAPIMixin):
+    def test_init_async_true(self, base_mixin_instance: APIMixin):
         """Test if api_view is instance of async API when async_api set to True."""
-        assert isinstance(base_mixin_instance.api_view, BaseAsyncAPI)
+        assert isinstance(base_mixin_instance.api_view, AsyncAPI)
 
     @pytest.mark.parametrize(
         'list_mixin_instance',
@@ -670,7 +647,7 @@ class TestMixins:
         with pytest.raises(AttributeError):
             list_mixin_instance.delete()
         with pytest.raises(AttributeError):
-            list_mixin_instance.update_single()
+            list_mixin_instance.update_one()
 
     @pytest.mark.parametrize(
         'list_mixin_instance',
@@ -730,7 +707,7 @@ class TestMixins:
         with pytest.raises(AttributeError):
             detail_mixin_instance.delete()
         with pytest.raises(AttributeError):
-            detail_mixin_instance.update_single()
+            detail_mixin_instance.update_one()
 
     @pytest.mark.parametrize(
         'list_mixin_instance_override_get_statement',
@@ -780,7 +757,7 @@ class TestMixins:
         with pytest.raises(AttributeError):
             create_mixin_instance.delete()
         with pytest.raises(AttributeError):
-            create_mixin_instance.update_single()
+            create_mixin_instance.update_one()
 
     @pytest.mark.parametrize(
         'update_mixin_instance',
@@ -789,9 +766,9 @@ class TestMixins:
     )
     def test_update_mixin(self, session, update_mixin_instance):
         """Test update mixin."""
-        update_mixin_instance.update_single(session=session, field_value=1, data={'id': 100})
+        update_mixin_instance.update_one(session=session, field_value=1, data={'id': 100})
 
-        api = BaseSyncAPI(
+        api = SyncAPI(
             model=SimpleTestOrm,
             pk_field='id'
         )
@@ -824,7 +801,7 @@ class TestMixins:
         """Test delete mixin."""
         delete_mixin_instance.delete(session=session, field_value=1)
 
-        api = BaseSyncAPI(
+        api = SyncAPI(
             model=SimpleTestOrm,
             pk_field='id'
         )
@@ -845,4 +822,4 @@ class TestMixins:
         with pytest.raises(AttributeError):
             delete_mixin_instance.create()
         with pytest.raises(AttributeError):
-            delete_mixin_instance.update_single()
+            delete_mixin_instance.update_one()
